@@ -4,6 +4,7 @@
 
 import sys
 import pprint
+import threading
 
 
 class WatchPrint:
@@ -12,7 +13,11 @@ class WatchPrint:
 
     def __call__(self, frame, elem, exec_info):
         p = self.printer
+        if threading.active_count() > 1:
+            curr_thread = threading.current_thread()
+            p(f"> {curr_thread.name}")
         p(self._file_string(exec_info))
+        p(f"> {self.getsourceline(exec_info)}")
         if elem.alias:
             p(f"{elem.alias}:")
         elif elem.default_alias:
@@ -25,6 +30,14 @@ class WatchPrint:
     def _file_string(self, exec_info):
         return f"> {exec_info[0]} ({exec_info[1]}:{exec_info[2]}):"
 
+    def getsourceline(self, exec_info):
+        try:
+            with open(exec_info[1]) as f:
+                lines = f.readlines()
+                return f"    {lines[exec_info[2] - 1].strip()}"
+        except (FileNotFoundError, PermissionError):
+            return "unable to locate the source"
+
     def printer(self, obj):
         if type(obj) is str:
             print(obj, file=self.file)
